@@ -1,3 +1,8 @@
+#!/usr/bin/perl -w
+# $Id: cmd.pl,v 1.4 2001/02/22 00:14:48 btrott Exp $
+
+use strict;
+
 use Net::SSH::Perl;
 use Net::SSH::Perl::Cipher;
 
@@ -6,6 +11,10 @@ print "Enter a host name to connect to: [$this_host] ";
 chomp(my $host = <STDIN>);
 print "\n";
 
+print "Enter the port number of the remote sshd: [ssh] ";
+chomp(my $port = <STDIN>);
+print "\n";
+
 print "Choose a cipher from the list:\n";
 my $supp = Net::SSH::Perl::Cipher::supported();
 for my $ciph (sort @$supp) {
@@ -15,6 +24,7 @@ printf "Enter a number: [%d] ", Net::SSH::Perl::Cipher::id('IDEA');
 chomp(my $c = <STDIN>);
 print "\n";
 my $ssh = Net::SSH::Perl->new($host || $this_host,
+    port => $port || 'ssh',
     cipher => Net::SSH::Perl::Cipher::name($c),
     debug => 1);
 
